function [ dist, flow, lpsolver_out ] = emd_pelwer(sig1, sig2, D, alpha)
%EMD_PELE Computes EMD [Pele and Werman, 2008] between two signatures.
%         Different from emd_banks is that the penalty is added to the
%         result of optimization (i.e., it does not participate in the
%         optimal flow search process). Numerically identical to emd_banks
%         if \alpha >= 0.5 and D is metric.
%
% Input:
%
%   sig1 - first signature; |sig1| = n
%   sig2 - second signature; |sig2| = m
%   D - ground distance; an n-by-m matrix, D(i,j) - cost of moving
%       a unit of weight from i'th item in sig1 to j'th item in sig2
%   alpha - parameter used to penalize for mass mismatch; alpha >= 0.5
%           for maintaining metricity of the distance measure
%
% Output:
%
%   dist - a real value representing the EMD between sig1 and sig2
%   flow - optimal flow of mass between the signatures
%

[dist, flow, lpsolver_out] = emd(sig1, sig2, D);

mass1 = sum(sig1);
mass2 = sum(sig2);
min_mass = min(mass1, mass2);
dist = dist * min_mass; % anti-normalization
mass_mismatch = abs(mass1 - mass2);
max_ground_dist = max(max(D));
dist = dist + alpha * max_ground_dist * mass_mismatch;

end