function [ dist ] = walk_dist(P, Q, adjmat)
%WALK_DIST ell_1 distance between user contentions in P and Q, where
% contention is measured as the difference of user state from the average
% state of this user's neighbor
% 
% P, Q - network states, adjmat -- transposed adjacency matrix

if(size(P, 1) < size(P, 2) || size(Q, 1) < size(Q, 2))
    error('Invalid network state dimensions.');
end
if(size(P, 1) ~= size(adjmat, 1))
    error('Netstate / adjmat size mismatch.');
end
if(size(adjmat, 1) ~= size(adjmat, 2))
    error('Invalid adjmat.');
end

connmat = adjmat > 0;

indegs = sum(connmat, 2);
indegs(indegs == 0) = 1;

P_avgnbr = connmat * P ./ indegs;
P_contention = abs(P - P_avgnbr);

Q_avgnbr = connmat * Q ./ indegs;
Q_contention = abs(Q - Q_avgnbr);

dist = norm(P_contention - Q_contention, 1) / length(P);

end

