function [ adjmat_new ] = double_edges(adjmat, delta)
%DOUBLE_EDGES Doubles each one-directed edge; weights new edges as
%   delta * {weight of existing reverse edge}. Weights are assumed
%   to be positive integers.
    if(~isscalar(delta) || delta <= 0)
        error('Invalid edge cost multiplier.');
    end
    if(~ismatrix(adjmat) || size(adjmat, 1) ~= size(adjmat, 2))
        error('Invalid adjmat.');
    end

    U = triu(adjmat, 1);
    L = tril(adjmat, -1);
    U = ifnzelse(U, L' * delta);
    L = ifnzelse(L, U' * delta);
    adjmat_new = L + diag(diag(adjmat)) + U;
end

function [ Z ] = ifnzelse(X, Y)
%IFNZELSE Sparse matrix version of ternary operator (Z = (X != 0) ? X : Y)
    bignum = abs(max(max(Y)));
    if(bignum >= Inf)
        error('Y contains large values.');
    end
    bignum = bignum + 1;

    Z = max((X ~= 0) .* bignum, Y);
    X_wins_indicator = (Z == bignum);
    Z(X_wins_indicator) = X(X_wins_indicator);
end