function [ success ] = parpool_init(nprocs, verbose)
%PARPOOL_INIT Tries to init a pool of <var>nprocs</var> workers.

try

nprocs_passed = exist('nprocs', 'var');
if(~exist('verbose', 'var'))
    verbose = false;
end

if(nprocs_passed && nprocs == 0)
    parpool_close();
    success = ~parpool_isactive();
    return;
end

current_parpool_size = parpool_size();
if(current_parpool_size > 0)
    if(nprocs_passed && nprocs ~= current_parpool_size)
        if(verbose)
            fprintf('Trying to close existing parallel pool of %d workers.\n', current_parpool_size);
        end
        parpool_close();
    else
        success = true;
        return;
    end
end

if(verbose)
    fprintf('Trying to init a parallel pool of %d workers.\n', nprocs);
end
    
if(exist('parpool', 'file'))
    if(nprocs_passed)
        evalc('parpool(nprocs)');
    else
        evalc('parpool()');
    end
elseif(exist('matlabpool', 'file'))
    if(nprocs_passed)
        evalc('matlabpool(nprocs)');
    else
        evalc('matlabpool()');
    end
end

success = parpool_isactive(verbose);
if(~success && verbose)
    fprintf(2, 'Unable to start a paralle pool.\n');
end

catch er
    success = false;
end
 
end