function [c l] = graphconncomp_alt(adj)
% 
%  Computing connected components of an undirected graph - assuming sA is symmetric
% 
%  Usage:
%   [c l] = graphconncomp_alt(adj);
% 
%  Inputs:
%   adj - sparse adjacency matrix
% 
%  Outputs:
%   l - components labels
%   c - number of connected components
% 
% 
%  Compile using:
%  >> mex -O -largeArrayDims graphconncomp_alt.cpp
% 
% 

 if(exist('graphconncomp_alt_mex', 'file') ~= 3)
    compiling = false;
    if(exist('graphconncomp_alt_mex_make.m', 'file') == 2)
        fprintf(2, 'graphconncomp_alt_mex.mex* file was not found. Trying to compile it.\n');
        compiling = true;
        graphconncomp_alt_mex_make;
    end
    if(exist('graphconncomp_alt_mex', 'file') ~= 3)
        error([
            'Accompanying graphconncomp_alt_mex.mex* file is not found. ', ...
            'The attempt to compile it has probably failed. ', ...
            'Try to compile it manually.'
        ]);
    elseif(compiling)
        fprintf(2, 'graphconncomp_alt_mex.mex* has been successfully compiled.\n');
    end
end

adj = spfun(@(x) ones(size(x)),adj);
if ~isequal(adj, adj')
    [ii, jj] = find(adj);
    adj = sparse([ii, jj], [jj, ii], ones(1, 2 * numel(ii)), size(adj, 1), size(adj, 2));
end
[l, c] = graphconncomp_alt_mex(adj);
l = double(l);

end