function [ yq ] = extrap(x, y, xq, k, method, visualize)
%EXTRAP Extrapolates a tabulated function y(x) at point xq using last k
% known values of y
     
    %% Extrapolation using a polynomial
    if(nargin < 4)
        k = Inf;
    end
    if(isnan(k) || k > length(y))
        k = length(y);
    end
    if(nargin < 5 || isscalar(method) && isnan(method))
        method = 'cubic';
    end
    if(k < 4 && (strcmp('cubic', method) || strcmp('pchip', method)))
        error('Not enough points for extrapolation.');
    end
    if(nargin < 6)
        visualize = false;
    end

    idx = length(y) - k + 1 : length(y);
    yq = interp1(x(idx), y(idx), xq, method, 'extrap');
    
    if(visualize)
       figure;
       plot(x, y, 'b-o');
       hold on;
       plot(xq, yq, '*r');
       hold off;
    end
end

%     warning('Manual extrapolation');
%     figure;
%     ax = gca;
%     plot(ax, x, y, 'b-o');
%     minmax = xlim;
%     xlim([min(minmax), max(minmax) + 5 * (x(length(x)) - x(length(x) - 1))]);
%     yq = input('What is the next value?');
%     return;