function [ new_hist ] = reshape_hist(hist)
%RESHAPE_HIST Accepts a histogram/signature and produces another
% histogram/signature of a different shape, yet, having the same
% total mass. This function does not provide any guarantees as to
% how the mass will be distributed in the new histogram.

n = max(size(hist));
new_hist = zeros(n, 1);

mass = sum(hist);
med = max(1, median(hist));
sdev = std(hist);

while(mass > 0)
    mass_chunk = max(1, round(med + sdev * randn(1, 1)));
    mass_chunk = max(0, min(mass, mass_chunk));
    dest = randi([1, n], 1, 1);
    mass = mass - mass_chunk;
    new_hist(dest) = new_hist(dest) + mass_chunk;
end

if(sum(hist) ~= sum(new_hist))
    error('Unable to reshape a histogram (mass mismatch).');
end

if(size(hist, 2) > size(hist, 1))
    new_hist = new_hist';
end

end